{% extends "base.html" %} {% block title %} {{ news.title }} {% endblock %} {% block headers %}

## {{ news.title }}

{% endblock headers %} {% block info %} {{ news.html_timestamps() }}
{{ facebook_like(news.get_absolute_url()) }} {% endblock info %} {% block content %} {{ news.html_admin_buttons() }}

{{ news.description|simpletags }}

{% if news.links.all() %}

{% for link in news.links.all() %}
- {{ link.description }}
{% endfor %}

{% endif %} {% if news.created_by.person %}

Posted by: {{ news.created_by.username }}

{% endif %} {% endblock %}